package
Version:
v0.0.0-...-8c8589c
Opens a new window with list of versions in this module.
Published: Sep 29, 2019
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ApiHandler interface {
HandleApiCall(url *url.URL, body []byte) (responseBody []byte, err error)
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.